##  Monitor and Measure Progress
Use the dedicated obsolescence risk management dashboard that is part of SAP LeanIX Technology Risk and Compliance for a centralized, real-time overview of current and future risk statuses for applications. The KPI panels of the dashboard offer insights into the number of applications facing obsolescence risk, both currently and projected into the future. This helps you monitor the evolving situation, as dealing with obsolescence risks becomes hard when the problem scales and hundreds of IT components start getting outdated.
The dashboard also offers visibility into addressed obsolescence risk, helping you track the progress of risk mitigation initiatives. Additionally, the Unaddressed Obsolescence Risk - Details panel offers specific information on mission-critical applications and IT components reaching end-of-life status, aiding proactive risk management to prevent critical risks from impacting the business.
![Obsolescence Risk Management Dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749992d7a441014b3e0bc8066ffd3b8_LowRes.png)
Obsolescence Risk Management Dashboard
Use reports to monitor the status of progress. For example, in the application matrix report, choose Organization and Business Capabilities for the two axes, and apply the Obsolescence: Unaddressed Risk Percentage view to gain insights into the proportion of unaddressed risks for applications within each business capability and organization. This view visualizes the percentage of IT components supporting each application with lifecycle information in Phase Out or End Of Life.
![Overview of Unaddressed Obsolescence Risk in Matrix Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fc97b7a4410148f40d466a673f723_LowRes.png)
Overview of Unaddressed Obsolescence Risk in Matrix Report
Use the Obsolescence: Mitigated Risk Percentage view in reports to visualize and effectively communicate the progress to concerned stakeholders and leadership. This view visualizes the percentage of IT components supporting each application whose risk has been addressed or accepted, providing clarity on the level of risk mitigation achieved.
![Overview of Mitigated Obsolescence Risk in Landscape Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747ea227a441014bbc59f3f222b4695_LowRes.png)
Overview of Mitigated Obsolescence Risk in Landscape Report
